clj-agent-tui.focus

Small focus-stack helpers for clj-agent-tui state maps.

Small focus-stack helpers for clj-agent-tui state maps.
raw docstring

activeclj

(active state)

Return the currently focused surface keyword.

Return the currently focused surface keyword.
sourceraw docstring

default-stackclj

source

focusclj

(focus state surface)

Replace focus stack with a single surface.

Replace focus stack with a single surface.
sourceraw docstring

pop-focusclj

(pop-focus state)

Pop the active focus surface, falling back to :composer.

Pop the active focus surface, falling back to :composer.
sourceraw docstring

push-focusclj

(push-focus state surface)

Push a focus surface, removing older duplicates first.

Push a focus surface, removing older duplicates first.
sourceraw docstring

stackclj

(stack state)
source

cljdoc builds & hosts documentation for Clojure/Script libraries