clj-agent-tui.fuzzy

Small deterministic fuzzy matcher for suggestion lists.

Small deterministic fuzzy matcher for suggestion lists.
raw docstring

filter-optionsclj

(filter-options query options)

Filter and sort option maps by fuzzy query.

Labels and values are the primary match surface. Descriptions are only used as a fallback when no option matches by label/value, so command searches do not show unrelated commands just because their help text contains a query letter.

Filter and sort option maps by fuzzy query.

Labels and values are the primary match surface. Descriptions are only used as
a fallback when no option matches by label/value, so command searches do not
show unrelated commands just because their help text contains a query letter.
sourceraw docstring

match-indicesclj

(match-indices query candidate)

Return sequential fuzzy match indices for query in candidate, or nil.

Return sequential fuzzy match indices for query in candidate, or nil.
sourceraw docstring

matches?clj

(matches? query candidate)
source

scoreclj

(score query candidate)

Score a query/candidate pair. Lower is better; nil means no match.

Score a query/candidate pair. Lower is better; nil means no match.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries