clj-agent-tui.runtime

Minimal local runtime that binds clj-agent-tui effects to provider/tool/session adapters.

Minimal local runtime that binds clj-agent-tui effects to provider/tool/session adapters.
raw docstring

apply-eventsclj

(apply-events state events)
source

drain-effectsclj

(drain-effects state effects)
(drain-effects state effects runtime)

Handle effects until the local queue is empty. Returns [state handled-effects].

Handle effects until the local queue is empty. Returns `[state handled-effects]`.
sourceraw docstring

handle-effectclj

(handle-effect state
               {:keys [provider registry session-path]}
               {:keys [type] :as effect})
source

submit-and-runclj

(submit-and-run state text)
(submit-and-run state text runtime)

Submit text, then handle all local effects with the supplied runtime adapters.

Submit text, then handle all local effects with the supplied runtime adapters.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries