clj-agent-tui.selection

Fuzzy-searchable selection list state and rendering.

Fuzzy-searchable selection list state and rendering.
raw docstring

append-queryclj

(append-query state text)
source

clamp-activeclj

(clamp-active state)
source

default-heightclj

source

delete-query-backwardclj

(delete-query-backward state)
source

move-activeclj

(move-active state delta)
source

render-selectionclj

(render-selection state)
(render-selection state {:keys [width] :or {width 80}})

Render a agent-code-like fuzzy suggestion surface.

Render a agent-code-like fuzzy suggestion surface.
sourceraw docstring

select-activeclj

(select-active state)
source

selected-optionclj

(selected-option state)
source

selectionclj

(selection options
           &
           {:keys [query active height title]
            :or {query "" active 0 height default-height title "Suggestions"}})

Create a selection state from option maps with :label, :value, :description.

Create a selection state from option maps with :label, :value, :description.
sourceraw docstring

set-queryclj

(set-query state query)
source

update-selectionclj

(update-selection state m)

Update selection state from charm key messages.

Returns [new-state action] where action is nil, :selected, or :closed.

Update selection state from charm key messages.

Returns `[new-state action]` where action is nil, `:selected`, or `:closed`.
sourceraw docstring

visible-optionsclj

(visible-options state)
source

cljdoc builds & hosts documentation for Clojure/Script libraries