Small data-first tool registry and scheduler for clj-agent-tui runtimes.
Small data-first tool registry and scheduler for clj-agent-tui runtimes.
(effect->events effect)(effect->events registry {:keys [type] :as effect})Turn a runtime effect into agent events. This is a local demo scheduler, not a production sandbox.
Turn a runtime effect into agent events. This is a local demo scheduler, not a production sandbox.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |