Small focus-stack helpers for clj-agent-tui state maps.
Small focus-stack helpers for clj-agent-tui state maps.
(active state)Return the currently focused surface keyword.
Return the currently focused surface keyword.
(focus state surface)Replace focus stack with a single surface.
Replace focus stack with a single surface.
(pop-focus state)Pop the active focus surface, falling back to :composer.
Pop the active focus surface, falling back to :composer.
(push-focus state surface)Push a focus surface, removing older duplicates first.
Push a focus surface, removing older duplicates first.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |