Small deterministic fuzzy matcher for suggestion lists.
Small deterministic fuzzy matcher for suggestion lists.
(filter-options query options)Filter and sort option maps by fuzzy query.
Labels and values are the primary match surface. Descriptions are only used as a fallback when no option matches by label/value, so command searches do not show unrelated commands just because their help text contains a query letter.
Filter and sort option maps by fuzzy query. Labels and values are the primary match surface. Descriptions are only used as a fallback when no option matches by label/value, so command searches do not show unrelated commands just because their help text contains a query letter.
(match-indices query candidate)Return sequential fuzzy match indices for query in candidate, or nil.
Return sequential fuzzy match indices for query in candidate, or nil.
(score query candidate)Score a query/candidate pair. Lower is better; nil means no match.
Score a query/candidate pair. Lower is better; nil means no match.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |