Provider abstraction for clj-agent-tui runtimes.
Provider abstraction for clj-agent-tui runtimes.
(claude-provider config)Return a Claude-shaped provider wrapper.
This is intentionally adapter-shaped but offline by default: pass :response-fn
for tests or bind this protocol to a real Anthropic client later.
Return a Claude-shaped provider wrapper. This is intentionally adapter-shaped but offline by default: pass `:response-fn` for tests or bind this protocol to a real Anthropic client later.
(deterministic-provider)(deterministic-provider {:keys [name response-fn] :or {name :deterministic}})Create a local provider used for demos/tests. It echoes the submitted text.
Create a local provider used for demos/tests. It echoes the submitted text.
(stream-events provider request)Return a bounded seq of clj-agent-tui.agent events for a request.
Return a bounded seq of clj-agent-tui.agent events for a request.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |