Minimal local runtime that binds clj-agent-tui effects to provider/tool/session adapters.
Minimal local runtime that binds clj-agent-tui effects to provider/tool/session adapters.
(drain-effects state effects)(drain-effects state effects runtime)Handle effects until the local queue is empty. Returns [state handled-effects].
Handle effects until the local queue is empty. Returns `[state handled-effects]`.
(handle-effect state
{:keys [provider registry session-path]}
{:keys [type] :as effect})(submit-and-run state text)(submit-and-run state text runtime)Submit text, then handle all local effects with the supplied runtime adapters.
Submit text, then handle all local effects with the supplied runtime adapters.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |