Fuzzy-searchable selection list state and rendering.
Fuzzy-searchable selection list state and rendering.
(render-selection state)(render-selection state {:keys [width] :or {width 80}})Render a agent-code-like fuzzy suggestion surface.
Render a agent-code-like fuzzy suggestion surface.
(selection options
&
{:keys [query active height title]
:or {query "" active 0 height default-height title "Suggestions"}})Create a selection state from option maps with :label, :value, :description.
Create a selection state from option maps with :label, :value, :description.
(update-selection state m)Update selection state from charm key messages.
Returns [new-state action] where action is nil, :selected, or :closed.
Update selection state from charm key messages. Returns `[new-state action]` where action is nil, `:selected`, or `:closed`.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |